@@ -26,7 +26,6 @@ from itertools import zip_longest, chain
 from pdfminer.pdfparser import PDFSyntaxError
 from pdfminer.psparser import PSEOF
 from pikepdf import Pdf
-from PyPDF2.utils import PdfReadError
 from typing import Any, Dict, List, Optional, Set, Tuple, Union, Iterable
 from urllib.parse import urlparse
 from zipfile import BadZipFile
@@ -157,7 +156,11 @@ def get_character_limit(pdf_field_tuple, char_width=6, row_height=12) -> Optiona
     3: vertical end
     """
     # Make sure it's the right kind of tuple
-    if len(pdf_field_tuple) < 3 or (pdf_field_tuple[3] and len(pdf_field_tuple[3]) < 4):
+    if (
+        len(pdf_field_tuple) < 4
+        or not pdf_field_tuple[3]
+        or len(pdf_field_tuple[3]) < 4
+    ):
         return None  # we can't really guess
 
     # Did a little testing for typical field width/number of chars with both w and e.
@@ -268,6 +271,7 @@ class DAField(DAObject):
         self.maxlength = get_character_limit(pdf_field_tuple)
         self.variable_name_guess = variable_name_guess
 
+        self.export_value = pdf_field_tuple[5] if len(pdf_field_tuple) >= 6 else ""
         if self.variable.endswith("_date"):
             self.field_type_guess = "date"
             self.variable_name_guess = "Date of " + self.variable[:-5].replace("_", " ")
@@ -280,7 +284,19 @@ class DAField(DAObject):
             )
             self.variable_name_guess = name_no_suffix.replace("_", " ").capitalize()
         elif pdf_field_tuple[4] == "/Btn":
-            self.field_type_guess = "yesno"
+            if str(self.export_value.lower()) in [
+                "yes",
+                "true",
+                "on",
+                "no",
+                "false",
+                "off",
+                "",
+            ]:
+                self.field_type_guess = "yesno"
+            else:
+                self.field_type_guess = "multiple choice radio"
+                self.choice_options = [self.export_value]
         elif pdf_field_tuple[4] == "/Sig":
             self.field_type_guess = "signature"
         elif self.maxlength and self.maxlength > 100:
@@ -415,6 +431,9 @@ class DAField(DAObject):
                 "field": self.attr_name("choices"),
                 "datatype": "area",
                 "js show if": f"['multiple choice dropdown','multiple choice combobox','multiselect', 'multiple choice radio', 'multiple choice checkboxes'].includes(val('{ self.attr_name('field_type') }'))",
+                "default": "\n".join(self.choice_options)
+                if hasattr(self, "choice_options")
+                else None,
                 "hint": "Like 'Descriptive name: key_name', or just 'Descriptive name'",
             }
         )
@@ -661,6 +680,26 @@ class DAFieldList(DAList):
         self.delitem(*mark_to_remove)
         self.there_are_any = len(self.elements) > 0
 
+    def consolidate_radios(self) -> None:
+        """Combines separate radio buttons into a single variable"""
+        radio_map: Dict[str, Any] = defaultdict(list)
+        mark_to_remove: List[int] = []
+        for idx, field in enumerate(self.elements):
+            if field.field_type_guess != "multiple choice radio":
+                continue
+
+            if len(radio_map[field.variable_name_guess]) > 0:
+                radio_map[field.variable_name_guess][0].choice_options.append(
+                    field.export_value
+                )
+            radio_map[field.variable_name_guess].append(field)
+
+            if len(radio_map[field.variable_name_guess]) > 1:
+                mark_to_remove.append(idx)
+
+        self.delitem(*mark_to_remove)
+        self.there_are_any = len(self.elements) > 0
+
     def consolidate_duplicate_fields(self, document_type: str = "pdf") -> None:
         """Removes all duplicate fields from a PDF (docx's are handled elsewhere) that really just
         represent a single variable, leaving one remaining field that writes all of the original vars
@@ -723,6 +762,7 @@ class DAFieldList(DAList):
             ):
                 for pike_info in pike_obj.Root.AcroForm.Fields:
                     pike_fields[str(pike_info.T)] = pike_info
+            pike_obj.close()
             for pdf_field_tuple, pike_info in zip_longest(all_fields, pike_fields):
                 pdf_field_name = pdf_field_tuple[0]
                 if pdf_field_name in pike_fields:
@@ -772,6 +812,7 @@ class DAFieldList(DAList):
                 if new_field.group in [DAFieldGroup.BUILT_IN, DAFieldGroup.RESERVED]:
                     new_field.label = new_field.variable_name_guess
 
+        self.consolidate_radios()
         self.consolidate_duplicate_fields(document_type)
         self.consolidate_yesnos()
 
@@ -1184,7 +1225,6 @@ class DAInterview(DAObject):
         generate_download_screen: bool = True,
         output_file: Optional[DAFile] = None,
     ) -> DAFile:
-
         # 2. Build data for folders_and_files and package_info
         folders_and_files = {
             "questions": [interview_mako_output],
@@ -1858,7 +1898,7 @@ def get_pdf_validation_errors(document: DAFile) -> Optional[ValidationError]:
         fields.add_fields_from_file(document)
     except ParsingException as ex:
         return ("parsing_exception", ex)
-    except (PDFSyntaxError, PdfReadError):
+    except PDFSyntaxError:
         return ("invalid_pdf", "Invalid PDF")
     except PSEOF:
         return (
@@ -1938,7 +1978,14 @@ def reflect_fields(
     mapping = []
     for field in pdf_field_tuples:
         if field[4] == "/Btn":
-            mapping.append({field[0]: "Yes"})
+            export_val = field[5] if len(field) >= 6 else ""
+            if str(export_val).lower() in ["yes", "on", "true", ""]:
+                mapping.append({field[0]: "Yes"})
+            else:
+                if field[0] not in [
+                    next(iter(field_val.keys())) for field_val in mapping
+                ]:
+                    mapping.append({field[0]: export_val})
         elif field[4] == "/Sig" and image_placeholder:
             mapping.append({field[0]: image_placeholder})
         else:
